@@ -208,6 +208,9 @@ $searchLimitOptions = array(
 $limitSelect = new htmlResponsiveSelect('searchLimit', $searchLimitOptions, array($conf->get_searchLimit()), _("LDAP search limit"), '222');
 $limitSelect->setHasDescriptiveElements(true);
 $row->add($limitSelect, 12);
+// DN part to hide
+$urlInput = new htmlResponsiveInputField(_("DN part to hide"), 'hideDnPart', $conf->getHideDnPart(), '292');
+$row->add($urlInput, 12);
 
 // access level is only visible in Pro version
 if (isLAMProVersion()) {
@@ -234,6 +237,11 @@ $advancedOptionsContent->add(new htmlResponsiveInputCheckbox('pagedResults', $pa
 // referential integrity overlay
 $referentialIntegrity = ($conf->isReferentialIntegrityOverlayActive());
 $advancedOptionsContent->add(new htmlResponsiveInputCheckbox('referentialIntegrityOverlay', $referentialIntegrity , _('Referential integrity overlay'), '269'), 12);
+// hide password prompt for expired passwords
+if (version_compare(phpversion(), '7.2.0') >= 0) {
+	$hidePasswordPromptForExpiredPasswords = ($conf->isHidePasswordPromptForExpiredPasswords());
+	$advancedOptionsContent->add(new htmlResponsiveInputCheckbox('hidePasswordPromptForExpiredPasswords', $hidePasswordPromptForExpiredPasswords, _('Hide password prompt for expired password'), '291'), 12);
+}
 
 // build advanced options box
 $advancedOptions = new htmlAccordion('advancedOptions_server', array(_('Advanced options') => $advancedOptionsContent), false);
@@ -455,7 +463,7 @@ $searchPasswordInput = new htmlResponsiveInputField(_("Bind password"), 'loginSe
 $searchPasswordInput->setIsPassword(true);
 $row->add($searchPasswordInput, 12);
 // HTTP authentication
-$row->add(new htmlResponsiveInputCheckbox('httpAuthentication', ($conf->getHttpAuthentication() == 'true'), _('HTTP authentication'), '223', true), 12);
+$row->add(new htmlResponsiveInputCheckbox('httpAuthentication', ($conf->getHttpAuthentication() == 'true'), _('HTTP authentication'), '223'), 12);
 $row->addVerticalSpacer('1rem');
 
 // 2factor authentication
@@ -585,10 +593,19 @@ function checkInput() {
 	else {
 		$conf->setReferentialIntegrityOverlay('false');
 	}
-/*	if (!$conf->set_cacheTimeout($_POST['cachetimeout'])) {
-		$errors[] = array("ERROR", _("Cache timeout is invalid!"));
-	}*/
+    if (version_compare(phpversion(), '7.2.0') >= 0) {
+	    if (isset($_POST['hidePasswordPromptForExpiredPasswords']) && ($_POST['hidePasswordPromptForExpiredPasswords'] == 'on')) {
+		    $conf->setHidePasswordPromptForExpiredPasswords('true');
+	    }
+	    else {
+		    $conf->setHidePasswordPromptForExpiredPasswords('false');
+	    }
+    }
+	/*	if (!$conf->set_cacheTimeout($_POST['cachetimeout'])) {
+			$errors[] = array("ERROR", _("Cache timeout is invalid!"));
+		}*/
 	$conf->set_searchLimit($_POST['searchLimit']);
+	$conf->setHideDnPart($_POST['hideDnPart']);
 	if (isLAMProVersion()) {
 		$conf->setAccessLevel($_POST['accessLevel']);
 		if (isset($_POST['pwdResetAllowSpecificPassword']) && ($_POST['pwdResetAllowSpecificPassword'] == 'on')) {
